@@ -4,8 +4,9 @@ from .consts import *
 
 class MarketAPI(Client):
 
-    def __init__(self, api_key='-1', api_secret_key='-1', passphrase='-1', use_server_time=False, flag='1', domain = 'https://www.okx.com'):
-        Client.__init__(self, api_key, api_secret_key, passphrase, use_server_time, flag, domain)
+    def __init__(self, api_key='-1', api_secret_key='-1', passphrase='-1', use_server_time=False, flag='1', domain = 'https://www.okx.com',debug = True):
+        Client.__init__(self, api_key, api_secret_key, passphrase, use_server_time, flag, domain,debug)
+
 
     # Get Tickers
     def get_tickers(self, instType, uly=''):
