@@ -4,8 +4,8 @@ from .consts import *
 
 class TradeAPI(Client):
 
-    def __init__(self, api_key='-1', api_secret_key='-1', passphrase='-1', use_server_time=False, flag='1', domain = 'https://www.okx.com'):
-        Client.__init__(self, api_key, api_secret_key, passphrase, use_server_time, flag, domain)
+    def __init__(self, api_key='-1', api_secret_key='-1', passphrase='-1', use_server_time=False, flag='1', domain = 'https://www.okx.com',debug = True):
+        Client.__init__(self, api_key, api_secret_key, passphrase, use_server_time, flag, domain,debug)
 
     # Place Order
     def place_order(self, instId, tdMode, side, ordType, sz, ccy='', clOrdId='', tag='', posSide='', px='',
